@@ -12,14 +12,14 @@ from .KMeans import KMeans
 
 _CLUSTERING_OPTIMIZER_STATE = [
 	'_min_k', '_max_k', '_n_jobs', '_models', '_kwargs', '_keep_models', '_distortions', '_inertias',
-	'_silhouette_scores', '_timeout', '_external_parallelization', '_n_external_jobs', '_n_internal_jobs'
+	'_silhouette_scores', '_timeout'
 ]
 
 
 class ClusteringOptimizer:
 	def __init__(
 			self, min_k, max_k, n_jobs=-1, keep_models=False, timeout=None,
-			external_parallelization=True, **kwargs
+			**kwargs
 	):
 		self._min_k = min_k
 		self._max_k = max_k
@@ -31,7 +31,6 @@ class ClusteringOptimizer:
 		self._inertias = None
 		self._silhouette_scores = None
 		self._timeout = timeout
-		self._external_parallelization = external_parallelization
 
 	def __getstate__(self):
 		return {
@@ -65,7 +64,7 @@ class ClusteringOptimizer:
 			else:
 				return k, None, kmeans.inertia, kmeans.distortion, kmeans.silhouette_score
 
-		if self._external_parallelization and self._n_jobs > 1:
+		if self._n_jobs > 1:
 
 			n_ks = self._max_k - self._min_k + 1
 			n_jobs = min(n_ks, self._n_jobs)
